boofun.core.gpu
=================

.. automodule:: boofun.core.gpu


   .. rubric:: Functions

   .. autosummary::

      auto_accelerate
      enable_gpu
      get_array_module
      gpu_influences
      gpu_noise_stability
      gpu_spectral_weight_by_degree
      gpu_walsh_hadamard
      is_gpu_available
      is_gpu_enabled
      to_cpu
      to_gpu

   .. rubric:: Classes

   .. autosummary::

      GPUBooleanFunctionOps
